import { Worker, isMainThread, parentPort, workerData } from 'worker_threads';
import { fileURLToPath } from 'url';
import { dirname } from 'path';

const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);

if (isMainThread) {
  // This code is executed in the main thread and will spawn a new worker.
  const worker = new Worker(__filename, {
    workerData: { value: 42 }
  });

  worker.on('message', (message) => {
    console.log(`Received message from worker: ${message}`);
  });

  worker.on('error', (error) => {
    console.error(`Worker error: ${error}`);
  });

  worker.on('exit', (code) => {
    if (code !== 0)
      console.error(`Worker stopped with exit code ${code}`);
  });
} else {
  // This code is executed in the worker thread.
  const { value } = workerData;
  parentPort?.postMessage(`The answer is ${value}`);
}
